{% extends "frame.html" %}
{% block content %}

<div class="block">
    <em>Error description</em>
    <pre>{{error.description}}</pre>
</div>

<div class="block">
    <em>Error code</em>
    <pre>{{error.code}}</pre>
</div>


{% endblock content %}