.button {
  display: inline-block;
  margin: 10px;
  padding: 8px 15px;
  background: #F6F6F6;
  border: 1px solid rgba(0,0,0,0.15);
  border-radius: 2px;
  transition: all 0.3s ease-out;
  box-shadow: inset 0 1px 0 rgba(255,255,255,0.5), 0 1px 0 #054d69, 0 0 1px 0 rgba(0,0,0,0.2);
  text-decoration: none;
  text-shadow: 0 1px rgba(255,255,255,0.7);
}

.button:hover  { 
  background: #eee;
}
